@@ -1,6 +1,10 @@
 #' Check duckdb extension and config settings
 #' @inheritParams open_curtain
 config_extensions <- function(conn) {
+  # temp fix for duckdb package errors, see: https://github.com/duckdb/duckdb-r/issues/600
+  fix_113 = utils::packageVersion("duckdb") == "1.1.3"
+  inst_sep = ifelse(fix_113, "core_nightly;", ";")
+
   extensions <- DBI::dbGetQuery(conn, (
     "SELECT extension_name, installed, loaded FROM duckdb_extensions()"
   ))
@@ -11,7 +15,7 @@ config_extensions <- function(conn) {
     status <- extensions[which(extensions$extension_name == ext), ]
 
     q <- ""
-    if (isFALSE(status$installed)) q <- paste(q, "INSTALL", ext, ";")
+    if (isFALSE(status$installed)) q <- paste(q, "INSTALL", ext, inst_sep)
 
     if (isFALSE(status$loaded)) q <- paste(q, "LOAD", ext, ";")
     return(q)
